﻿using System.Net.Http;
using System.Threading.Tasks;
using Newtonsoft.Json;
using PokeApp.Data;

public class PokemonService
{
    private readonly HttpClient _httpClient;

    public PokemonService(HttpClient httpClient)
    {
        _httpClient = httpClient;
    }

    public async Task<Pokemon> GetPokemonAsync(string species)
    {
        var url = $"https://pokeapi.co/api/v2/pokemon/{species}/";
        var response = await _httpClient.GetStringAsync(url);
        var pokemon = JsonConvert.DeserializeObject<Pokemon>(response);
        return pokemon;
    }

    // Method to get detailed info for a single Pokémon by URL
    public async Task<Pokemon> GetPokemonByUrlAsync(string url)
    {
        var response = await _httpClient.GetStringAsync(url);
        var pokemon = JsonConvert.DeserializeObject<Pokemon>(response);
        return pokemon;
    }

    // Method to get all Pokémon names and URLs, then fetch detailed info for each
    public async Task<List<Pokemon>> GetAllPokemonWithDetailsAsync()
    {
        var url = "https://pokeapi.co/api/v2/pokemon?limit=30";
        var response = await _httpClient.GetStringAsync(url);
        var pokemonListResponse = JsonConvert.DeserializeObject<PokemonListResponse>(response);

        var pokemonDetailsList = new List<Pokemon>();

        foreach (var pokemonItem in pokemonListResponse.Results)
        {
            var detailedPokemon = await GetPokemonByUrlAsync(pokemonItem.Url);
            pokemonDetailsList.Add(detailedPokemon);
        }

        return pokemonDetailsList;
    }
}
